==> optgroup_taxonomy_select-8.x-1.0.tar.gz: optgroup_taxonomy_select/src/Plugin/Field/FieldWidget/OptgroupTermSelectWidget.php <==
<?php

namespace Drupal\optgroup_taxonomy_select\Plugin\Field\FieldWidget;

use Drupal\Component\Utility\Html;
use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Field\Plugin\Field\FieldWidget\OptionsWidgetBase;
/**
 * Plugin implementation of the 'optgroup_term_select' widget.
 *
 * @FieldWidget(
 *   id = "optgroup_term_select",
 *   label = @Translation("Optgroup Term Select"),
 *   field_types = {
 *     "entity_reference",
 *     "list_integer",
 *     "list_float",
 *     "list_string"
 *   },
 *   multiple_values = TRUE
 * )
 */
class OptgroupTermSelectWidget extends OptionsWidgetBase {
  /**
   * {@inheritdoc}
   */
  public function formElement(FieldItemListInterface $items, $delta, array $element, array &$form, FormStateInterface $form_state) {
    $element = parent::formElement($items, $delta, $element, $form, $form_state);
    $field_definition = $items->getFieldDefinition();
    $target_bundle = $field_definition->getSettings();
    $voc_list = $target_bundle['handler_settings']['target_bundles'];
      foreach ($voc_list as $key => $value) {
        $data = \Drupal::entityTypeManager()->getStorage('taxonomy_term')->loadTree($key);
        foreach ($data as $item) {
        if ($item->depth == 0){
          $parent = $item->name;
          //$result[]
        }else {
            $result[$parent][$item->tid] = $item->name;
        }
      }
      }
    $element += [
      '#type' => 'select',
      '#options' => $result,
      '#default_value' => $this->getSelectedOptions($items),
      // Do not display a 'multiple' select box if there is only one option.
      '#multiple' => $this->multiple && count($this->options) > 1,
    ];
    return $element;
  }
  /**
   * {@inheritdoc}
   */
  protected function sanitizeLabel(&$label) {
    // Select form inputs allow unencoded HTML entities, but no HTML tags.
    $label = Html::decodeEntities(strip_tags($label));
  }
  /**
   * {@inheritdoc}
   */
  protected function supportsGroups() {
    return TRUE;
  }
  /**
   * {@inheritdoc}
   */
  protected function getEmptyLabel() {
    if ($this->multiple) {
      // Multiple select: add a 'none' option for non-required fields.
      if (!$this->required) {
        return t('- None -');
      }
    }
    else {
      // Single select: add a 'none' option for non-required fields,
      // and a 'select a value' option for required fields that do not come
      // with a value selected.
      if (!$this->required) {
        return t('- None -');
      }
      if (!$this->has_value) {
        return t('- Select a value -');
      }
    }
  }
}

==> optgroup_taxonomy_select-8.x-1.1.tar.gz: optgroup_taxonomy_select/src/Plugin/Field/FieldWidget/OptgroupTermSelectWidget.php <==
<?php

namespace Drupal\optgroup_taxonomy_select\Plugin\Field\FieldWidget;

use Drupal\Component\Utility\Html;
use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Field\Plugin\Field\FieldWidget\OptionsWidgetBase;

/**
 * Plugin implementation of the 'optgroup_term_select' widget.
 *
 * @FieldWidget(
 *   id = "optgroup_term_select",
 *   label = @Translation("Optgroup Term Select"),
 *   field_types = {
 *     "entity_reference"
 *   },
 *   multiple_values = TRUE
 * )
 */
class OptgroupTermSelectWidget extends OptionsWidgetBase {

  /**
   * {@inheritdoc}
   */
  public function formElement(FieldItemListInterface $items, $delta, array $element, array &$form, FormStateInterface $form_state) {
    $element = parent::formElement($items, $delta, $element, $form, $form_state);
    $field_definition = $items->getFieldDefinition();
    $target_bundle = $field_definition->getSettings();
    $voc_list = $target_bundle['handler_settings']['target_bundles'];
    foreach ($voc_list as $key => $value) {
      $data = \Drupal::entityTypeManager()->getStorage('taxonomy_term')->loadTree($key);
      foreach ($data as $item) {
        if ($item->depth == 0) {
          $parent = $item->name;
        }
        else {
          $result[$parent][$item->tid] = $item->name;
        }
      }
    }
    $element += [
      '#type' => 'select',
      '#options' => $result,
      '#default_value' => $this->getSelectedOptions($items),
      // Do not display a 'multiple' select box if there is only one option.
      '#multiple' => $this->multiple && count($this->options) > 1,
    ];
    return $element;
  }

  /**
   * {@inheritdoc}
   */
  protected function sanitizeLabel(&$label) {
    // Select form inputs allow unencoded HTML entities, but no HTML tags.
    $label = Html::decodeEntities(strip_tags($label));
  }

  /**
   * {@inheritdoc}
   */
  protected function supportsGroups() {
    return TRUE;
  }

  /**
   * {@inheritdoc}
   */
  protected function getEmptyLabel() {
    if ($this->multiple) {
      // Multiple select: add a 'none' option for non-required fields.
      if (!$this->required) {
        return $this->t('- None -');
      }
    }
    else {
      // Single select: add a 'none' option for non-required fields,
      // and a 'select a value' option for required fields that do not come
      // with a value selected.
      if (!$this->required) {
        return $this->t('- None -');
      }
      if (!$this->has_value) {
        return $this->t('- Select a value -');
      }
    }
  }

}
